==> touhoulittlemaid-fabric-1.21.1-0.1.0-neo1.3.7-sources.jar: com/github/tartaricacid/touhoulittlemaid/entity/chatbubble/implement/ImageChatBubbleData.java <==
package com.github.tartaricacid.touhoulittlemaid.entity.chatbubble.implement;

import com.github.tartaricacid.touhoulittlemaid.TouhouLittleMaid;
import com.github.tartaricacid.touhoulittlemaid.client.renderer.entity.chatbubble.IChatBubbleRenderer;
import com.github.tartaricacid.touhoulittlemaid.client.renderer.entity.chatbubble.implement.ImageChatBubbleRenderer;
import com.github.tartaricacid.touhoulittlemaid.entity.chatbubble.IChatBubbleData;
import net.fabricmc.api.EnvType;
import net.fabricmc.api.Environment;
import net.minecraft.class_2540;
import net.minecraft.class_2960;

public class ImageChatBubbleData implements IChatBubbleData {
    public static final class_2960 ID = class_2960.method_60655(TouhouLittleMaid.MOD_ID, "image");

    private final int existTick;
    private final class_2960 bg;
    private final class_2960 image;
    private final int width;
    private final int height;
    private final int uOffset;
    private final int vOffset;
    private final int textureWidth;
    private final int textureHeight;
    private final int priority;

    @Environment(EnvType.CLIENT)
    private IChatBubbleRenderer renderer;

    private ImageChatBubbleData(int existTick, class_2960 bg, class_2960 image, int width, int height,
                                int uOffset, int vOffset, int textureWidth, int textureHeight, int priority) {
        this.existTick = existTick;
        this.bg = bg;
        this.image = image;
        this.width = width;
        this.height = height;
        this.uOffset = uOffset;
        this.vOffset = vOffset;
        this.textureWidth = textureWidth;
        this.textureHeight = textureHeight;
        this.priority = priority;
    }

    public static ImageChatBubbleData create(class_2960 image, int width, int height) {
        return new ImageChatBubbleData(DEFAULT_EXIST_TICK, TYPE_2, image, width, height, 0, 0, 256, 256, DEFAULT_PRIORITY);
    }

    public static ImageChatBubbleData create(class_2960 image, int width, int height, int uOffset, int vOffset) {
        return new ImageChatBubbleData(DEFAULT_EXIST_TICK, TYPE_2, image, width, height, uOffset, vOffset, 256, 256, DEFAULT_PRIORITY);
    }

    public static ImageChatBubbleData create(int existTick, class_2960 bg, class_2960 image, int width, int height,
                                             int uOffset, int vOffset, int textureWidth, int textureHeight, int priority) {
        return new ImageChatBubbleData(existTick, bg, image, width, height, uOffset, vOffset, textureWidth, textureHeight, priority);
    }

    @Override
    public int existTick() {
        return this.existTick;
    }

    @Override
    public class_2960 id() {
        return ID;
    }

    @Override
    public int priority() {
        return this.priority;
    }

    @Override
    @Environment(EnvType.CLIENT)
    public IChatBubbleRenderer getRenderer(IChatBubbleRenderer.Position position) {
        if (this.renderer == null) {
            this.renderer = new ImageChatBubbleRenderer(this.width, this.height, this.uOffset, this.vOffset,
                    this.textureWidth, this.textureHeight, this.bg, this.image);
        }
        return this.renderer;
    }

    public static class ImageChatSerializer implements IChatBubbleData.ChatSerializer {
        @Override
        public IChatBubbleData readFromBuff(class_2540 buf) {
            int width = buf.method_10816();
            int height = buf.method_10816();
            int uOffset = buf.method_10816();
            int vOffset = buf.method_10816();
            int textureWidth = buf.method_10816();
            int textureHeight = buf.method_10816();
            class_2960 bg = buf.method_10810();
            class_2960 image = buf.method_10810();
            return new ImageChatBubbleData(DEFAULT_EXIST_TICK, bg, image, width, height,
                    uOffset, vOffset, textureWidth, textureHeight, DEFAULT_PRIORITY);
        }

        @Override
        public void writeToBuff(class_2540 buf, IChatBubbleData data) {
            ImageChatBubbleData imageChat = (ImageChatBubbleData) data;
            buf.method_10804(imageChat.width);
            buf.method_10804(imageChat.height);
            buf.method_10804(imageChat.uOffset);
            buf.method_10804(imageChat.vOffset);
            buf.method_10804(imageChat.textureWidth);
            buf.method_10804(imageChat.textureHeight);
            buf.method_10812(imageChat.bg);
            buf.method_10812(imageChat.image);
        }
    }
}

==> touhoulittlemaid-fabric-1.21.1-0.2.0-neo1.4.2-sources.jar: com/github/tartaricacid/touhoulittlemaid/entity/chatbubble/implement/ImageChatBubbleData.java <==
package com.github.tartaricacid.touhoulittlemaid.entity.chatbubble.implement;

import com.github.tartaricacid.touhoulittlemaid.TouhouLittleMaid;
import com.github.tartaricacid.touhoulittlemaid.client.renderer.entity.chatbubble.IChatBubbleRenderer;
import com.github.tartaricacid.touhoulittlemaid.client.renderer.entity.chatbubble.implement.ImageChatBubbleRenderer;
import com.github.tartaricacid.touhoulittlemaid.entity.chatbubble.IChatBubbleData;
import net.fabricmc.api.EnvType;
import net.fabricmc.api.Environment;
import net.minecraft.class_2540;
import net.minecraft.class_2960;

public class ImageChatBubbleData implements IChatBubbleData {
    public static final class_2960 ID = class_2960.method_60655(TouhouLittleMaid.MOD_ID, "image");

    private final int existTick;
    private final class_2960 bg;
    private final class_2960 image;
    private final int width;
    private final int height;
    private final int uOffset;
    private final int vOffset;
    private final int textureWidth;
    private final int textureHeight;
    private final int priority;

    @Environment(EnvType.CLIENT)
    private IChatBubbleRenderer renderer;

    private ImageChatBubbleData(int existTick, class_2960 bg, class_2960 image, int width, int height,
                                int uOffset, int vOffset, int textureWidth, int textureHeight, int priority) {
        this.existTick = existTick;
        this.bg = bg;
        this.image = image;
        this.width = width;
        this.height = height;
        this.uOffset = uOffset;
        this.vOffset = vOffset;
        this.textureWidth = textureWidth;
        this.textureHeight = textureHeight;
        this.priority = priority;
    }

    public static ImageChatBubbleData create(class_2960 image, int width, int height) {
        return new ImageChatBubbleData(DEFAULT_EXIST_TICK, TYPE_2, image, width, height, 0, 0, 256, 256, DEFAULT_PRIORITY);
    }

    public static ImageChatBubbleData create(class_2960 image, int width, int height, int uOffset, int vOffset) {
        return new ImageChatBubbleData(DEFAULT_EXIST_TICK, TYPE_2, image, width, height, uOffset, vOffset, 256, 256, DEFAULT_PRIORITY);
    }

    public static ImageChatBubbleData singleImage(class_2960 image, int width, int height) {
        return new ImageChatBubbleData(DEFAULT_EXIST_TICK, TYPE_2, image, width, height, 0, 0, width, height, DEFAULT_PRIORITY);
    }

    public static ImageChatBubbleData create(int existTick, class_2960 bg, class_2960 image, int width, int height,
                                             int uOffset, int vOffset, int textureWidth, int textureHeight, int priority) {
        return new ImageChatBubbleData(existTick, bg, image, width, height, uOffset, vOffset, textureWidth, textureHeight, priority);
    }

    @Override
    public int existTick() {
        return this.existTick;
    }

    @Override
    public class_2960 id() {
        return ID;
    }

    @Override
    public int priority() {
        return this.priority;
    }

    @Override
    @Environment(EnvType.CLIENT)
    public IChatBubbleRenderer getRenderer(IChatBubbleRenderer.Position position) {
        if (this.renderer == null) {
            this.renderer = new ImageChatBubbleRenderer(this.width, this.height, this.uOffset, this.vOffset,
                    this.textureWidth, this.textureHeight, this.bg, this.image);
        }
        return this.renderer;
    }

    public static class ImageChatSerializer implements IChatBubbleData.ChatSerializer {
        @Override
        public IChatBubbleData readFromBuff(class_2540 buf) {
            int width = buf.method_10816();
            int height = buf.method_10816();
            int uOffset = buf.method_10816();
            int vOffset = buf.method_10816();
            int textureWidth = buf.method_10816();
            int textureHeight = buf.method_10816();
            class_2960 bg = buf.method_10810();
            class_2960 image = buf.method_10810();
            return new ImageChatBubbleData(DEFAULT_EXIST_TICK, bg, image, width, height,
                    uOffset, vOffset, textureWidth, textureHeight, DEFAULT_PRIORITY);
        }

        @Override
        public void writeToBuff(class_2540 buf, IChatBubbleData data) {
            ImageChatBubbleData imageChat = (ImageChatBubbleData) data;
            buf.method_10804(imageChat.width);
            buf.method_10804(imageChat.height);
            buf.method_10804(imageChat.uOffset);
            buf.method_10804(imageChat.vOffset);
            buf.method_10804(imageChat.textureWidth);
            buf.method_10804(imageChat.textureHeight);
            buf.method_10812(imageChat.bg);
            buf.method_10812(imageChat.image);
        }
    }
}
